@@ -42,6 +42,10 @@ use App::CELL qw( $CELL );
 use App::Dochazka::CLI::Commands::Activity qw( 
     activity_all 
 );
+use App::Dochazka::CLI::Commands::Component qw( 
+    component_path
+    generate_report
+);
 use App::Dochazka::CLI::Commands::Employee qw( 
     employee_ldap
     employee_ldap_import
@@ -580,6 +584,11 @@ our $dispatch_map = {
     "ACTIVITY" => \&activity_all,
     "ACTIVITY ALL" => \&activity_all,
     "ACTIVITY ALL DISABLED" => \&activity_all,
+    
+    # Report commands
+    #"COMPONENT PATH _PATH" => \&component_path,
+    "GENERATE REPORT _PATH" => \&generate_report,
+    "GENERATE REPORT _PATH _JSON" => \&generate_report,
 
     # Employee commands
     "EMPLOYEE" => \&employee_profile,
