@@ -48,6 +48,7 @@ use App::Dochazka::CLI::Util qw(
     rest_error
     truncate_to
 );
+use App::Dochazka::Common::Model::Interval;
 use Data::Dumper;
 use Date::Calc qw( Days_in_Month );
 use Exporter 'import';
@@ -95,6 +96,7 @@ our @EXPORT_OK = qw(
     interval_new_date_time_date1_time1
     interval_new_time_time1
     interval_new_timerange
+    interval_summary
 );
 
 
@@ -186,6 +188,8 @@ sub interval_new_timerange {
     EMPLOYEE_SPEC INTERVAL FETCH _DATE
     INTERVAL FILLUP _DATE
     EMPLOYEE_SPEC INTERVAL FILLUP _DATE
+    INTERVAL SUMMARY _DATE
+    EMPLOYEE_SPEC INTERVAL SUMMARY _DATE
     INTERVAL DELETE _DATE
     EMPLOYEE_SPEC INTERVAL DELETE _DATE
 
@@ -228,6 +232,8 @@ sub interval_date {
     EMPLOYEE_SPEC INTERVAL FETCH _DATE _HYPHEN _DATE1
     INTERVAL FILLUP _DATE _HYPHEN _DATE1
     EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1
+    INTERVAL SUMMARY _DATE _HYPHEN _DATE1
+    EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _HYPHEN _DATE1
     INTERVAL DELETE _DATE _HYPHEN _DATE1
     EMPLOYEE_SPEC INTERVAL DELETE _DATE _HYPHEN _DATE1
 
@@ -264,6 +270,8 @@ sub interval_date_date1 {
     EMPLOYEE_SPEC INTERVAL FETCH _MONTH [_NUM]
     INTERVAL FILLUP _MONTH [_NUM]
     EMPLOYEE_SPEC INTERVAL FILLUP _MONTH [_NUM]
+    INTERVAL SUMMARY _MONTH [_NUM]
+    EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH [_NUM]
     INTERVAL DELETE _MONTH [_NUM]
     EMPLOYEE_SPEC INTERVAL DELETE _MONTH [_NUM]
 
@@ -308,6 +316,8 @@ sub interval_month {
     EMPLOYEE_SPEC INTERVAL FETCH _NUM [_NUM1]
     INTERVAL FILLUP _NUM [_NUM1]
     EMPLOYEE_SPEC INTERVAL FILLUP _NUM [_NUM1]
+    INTERVAL SUMMARY _NUM [_NUM1]
+    EMPLOYEE_SPEC INTERVAL SUMMARY _NUM [_NUM1]
     INTERVAL DELETE _NUM [_NUM1]
     EMPLOYEE_SPEC INTERVAL DELETE _NUM [_NUM1]
 
@@ -351,6 +361,8 @@ sub interval_num_num1 {
 
     INTERVAL FILLUP _TSRANGE
     EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE
+    INTERVAL SUMMARY _TSRANGE
+    EMPLOYEE_SPEC INTERVAL SUMMARY _TSRANGE
 
 =cut
 
@@ -380,6 +392,8 @@ sub interval_fillup_tsrange {
     EMPLOYEE_SPEC INTERVAL FETCH
     INTERVAL FILLUP
     EMPLOYEE_SPEC INTERVAL FILLUP
+    INTERVAL SUMMARY
+    EMPLOYEE_SPEC INTERVAL SUMMARY
     INTERVAL DELETE
     EMPLOYEE_SPEC INTERVAL DELETE
 
@@ -412,6 +426,8 @@ sub _interval_fillup_delete_print {
         return _fillup( emp_obj => $emp, tsrange => $tsr, dry_run => $dry );
     } elsif ( $th->{'DELETE'} ) {
         return _delete_intervals_tsrange( $emp->eid, $tsr );
+    } elsif ( $th->{'SUMMARY'} ) {
+        return _interval_summary( $emp->eid, $tsr );
     } else {
         return _print_intervals_tsrange( $emp, $tsr );
     }
@@ -574,15 +590,25 @@ sub _print_intervals_tsrange {
     $pl .= "in the range $tsr\n\n";
 
     my $t = Text::Table->new( 'IID', 'Begin', 'End', 'Code', 'Description' );
-    for my $int ( @{ $status->payload } ) {
+    my $partial_intervals_present = 0;
+    for my $props ( @{ $status->payload } ) {
+        my $int = App::Dochazka::Common::Model::Interval->spawn( $props );
+        my $iid;
+        if ( $int->partial ) {
+            $partial_intervals_present = 1;
+            $iid = $int->iid . '**';
+        } else {
+            $iid = $int->iid;
+        }
         $t->add( 
-            $int->{'iid'},
-            _begin_and_end_from_intvl( $int->{'intvl'} ),
-            $int->{'code'},
-            truncate_to( $int->{'long_desc'} ),
+            $iid,
+            _begin_and_end_from_intvl( $int->intvl ),
+            $int->code,
+            truncate_to( $int->long_desc ),
         );
     }
     $pl .= $t;
+    $pl .= "\nPartial intervals signified by **\n";
 
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $pl );
 }
@@ -611,11 +637,26 @@ sub _delete_intervals_tsrange {
     my ( $eid, $tsr ) = @_;
     my $status = send_req( 'DELETE', "interval/eid/$eid/$tsr" );
     return $status unless $status->ok;
-    my $count = $status->payload;
+    my $count = $status->{'count'};
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', 
         payload => "$count intervals deleted in range $tsr" );
 }
 
+=head3 _interval_summary
+
+Given an EID and a tsrange, call the "interval/sumary/eid/:eid/:tsrange"
+resource.
+
+=cut
+
+sub _interval_summary {
+    my ( $eid, $tsr ) = @_;
+    my $status = send_req( 'GET', "interval/summary/eid/$eid/$tsr" );
+    return $status unless $status->ok;
+    return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', 
+        payload => $status->payload );
+}
+
 =head3 _fillup
 
 =cut
